/services/content_creator_insights_service.proto

--- v22/services/content_creator_insights_service.proto 2026-02-25 22:50:24.000000000 +0000
+++ v23/services/content_creator_insights_service.proto 2026-02-25 22:50:33.000000000 +0000
@@ -327,11 +327,19 @@
       channel_attributes = 5;

   // The top 10 videos for the channel.
-  repeated google.ads.googleads.v22.common.AudienceInsightsAttributeMetadata
+  repeated google.ads.googleads.v23.common.AudienceInsightsAttributeMetadata
       top_videos = 8;

+  // The languages associated with the content made by a channel.
+  repeated LanguageDistribution language_distributions = 15;
+
   // Metadata string associated with the type of channel.
   string channel_type = 6;
+
+  // The relevance score of the channel to the topic being searched for weighted
+  // by views. The value is between 0 and 1, with 1 being the most relevant.
+  // Only populated for trends using search_topics.
+  double relevance_score = 16;
 }

 // A collection of audience attributes that describe an audience of viewers.
@@ -366,7 +374,14 @@
   TrendInsightMetrics trend_metrics = 2;

   // The direction of trend (such as RISING or DECLINING).
-  google.ads.googleads.v22.enums.InsightsTrendEnum.InsightsTrend trend = 3;
+  google.ads.googleads.v23.enums.InsightsTrendEnum.InsightsTrend trend = 3;
+
+  // 12 months of historical data for the trend, including the most recent month
+  // the TrendInsight represents. Each data point represents 1 month of data and
+  // the comparison period is 1 month. The data points are ordered from most
+  // recent month to least recent month. Only populated for trends using
+  // search_topics.
+  repeated TrendInsightDataPoint trend_data_points = 6;

   // Related videos for this topic. Only populated for trends using
   // search_topics.
@@ -380,12 +395,44 @@

 // Metrics associated with a trend insight.
 message TrendInsightMetrics {
   // The number of views for this trend. This is only populated for SearchTopics
   // requests.
   int64 views_count = 1;

+  // Views value normalized to be in the range 0-100. This is only populated for
+  // SearchTopics requests.
+  int64 views_indexed_value = 4;
+
   // The fraction (from 0 to 1 inclusive) of the requested audience that has
   // has searched or viewed this trend. This is only populated for
   // SearchAudience requests.
   double audience_share = 2;
+
+  // The percentage of the change in the trend's value over the comparison
+  // period, where 1.0 represents 100%. If this is 0, it means that the trend is
+  // emerging (new) or sustained (existing but unchanged).
+  double trend_change_percent = 3;
+}
+
+// Trend data for a specific month.
+message TrendInsightDataPoint {
+  // The month that the trend data point represents in the string format
+  // "YYYY-MM".
+  string month = 1;
+
+  // Metrics associated with this trend and month. The comparison period for
+  // these metrics is 1 month.
+  TrendInsightMetrics trend_metrics = 2;
+}
+
+// Languages that pertain to a YouTube channel based on the channel content.
+// Only languages above a certain proportion threshold are included.
+message LanguageDistribution {
+  // [Language
+  // code](https://developers.google.com/google-ads/api/reference/data/codes-formats#languages)
+  // of the language for the YouTube channel.
+  string language_code = 1;
+
+  // The proportion (between 0 and 1)  of the channel's videos in the language.
+  double proportion = 2;
 }
@@ -380,12 +395,44 @@
 // Metrics associated with a trend insight.
 message TrendInsightMetrics {
-  // The number of views for this trend. This is only populated for SearchTopics
-  // requests.
+  // The number of views for this trend. This is only populated for the latest
+  // month of data for SearchTopics requests.
   int64 views_count = 1;
